Index: fetch_configs/fletch.py |
diff --git a/recipes/fletch.py b/fetch_configs/fletch.py |
similarity index 88% |
rename from recipes/fletch.py |
rename to fetch_configs/fletch.py |
index 1938ea7e4173b49f95e9d55d0604abdd1e9cce69..071d5923144ccb4feb8dd89cd5a22a0f63ba80bb 100644 |
--- a/recipes/fletch.py |
+++ b/fetch_configs/fletch.py |
@@ -4,12 +4,12 @@ |
import sys |
-import recipe_util # pylint: disable=F0401 |
+import config_util # pylint: disable=F0401 |
# This class doesn't need an __init__ method, so we disable the warning |
# pylint: disable=W0232 |
-class Fletch(recipe_util.Recipe): |
- """Basic Recipe class for Fletch.""" |
+class Fletch(config_util.Config): |
+ """Basic Config class for Fletch.""" |
@staticmethod |
def fetch_spec(props): |